@@ -1,9 +1,9 @@
 library(shiny)
+library(DT)
+
 
 shinyUI(fluidPage(
   
-  headerPanel("signalHsmm"),
-  
   sidebarLayout(
     sidebarPanel(
       includeMarkdown("readme.md"),
